==> rustsec-admin-0.4.1.crate: rustsec-admin-0.4.1/CHANGELOG.md <==
## 0.4.1 (2021-04-30)
- Display more information on the website ([#133])

[#133]: https://github.com/RustSec/rustsec-admin/pull/133

## 0.4.0 (2021-03-06)
- Use a fully Rust based solution for rendering web page ([#115])
- Use rust-embed for static assets ([#122])
- Add argument to change where website is outputted ([#123])

[#115]: https://github.com/RustSec/rustsec-admin/pull/115
[#122]: https://github.com/RustSec/rustsec-admin/pull/122
[#123]: https://github.com/RustSec/rustsec-admin/pull/123

## 0.3.5 (2021-03-06) [YANKED]

## 0.3.4 (2021-01-26)
- Bump `rustsec` crate to v0.23 ([#112])

[#112]: https://github.com/RustSec/rustsec-admin/pull/112

## 0.3.3 (2021-01-04)
- assigner: fix "new year's" bug ([#102])

[#102]: https://github.com/RustSec/rustsec-admin/pull/102

## 0.3.2 (2020-11-23) 
- Bump `rustsec` crate to v0.23.0-pre ([#96])

[#96]: https://github.com/RustSec/rustsec-admin/pull/96

## 0.3.1 (2020-10-27)
- Bump `rustsec` crate to v0.22.2 ([#88])

[#88]: https://github.com/RustSec/rustsec-admin/pull/88

## 0.3.0 (2020-10-26)
- Bump `rustsec` crate dependency to v0.22 ([#83])
- `assign-id`: fix command after V3 advisory format migration ([#79], [#81])

[#83]: https://github.com/RustSec/rustsec-admin/pull/83
[#81]: https://github.com/RustSec/rustsec-admin/pull/81
[#79]: https://github.com/RustSec/rustsec-admin/pull/79

## 0.2.1 (2020-07-24)
- Output mode for use with the production github action ([#62])

[#62]: https://github.com/RustSec/rustsec-admin/pull/62

## 0.2.0 (2020-06-29)
- linter: refactor into `Linter` struct; check all files ([#55])
- Bump `rustsec` crate to v0.21.0 ([#52])
- `assign-id` subcommand ([#41])

[#55]: https://github.com/RustSec/rustsec-admin/pull/55
[#52]: https://github.com/RustSec/rustsec-admin/pull/52
[#41]: https://github.com/RustSec/rustsec-admin/pull/41

## 0.1.1 (2019-10-07)
- Bump `rustsec` crate to v0.15.1 ([#7])

[#7]: https://github.com/RustSec/rustsec-admin/pull/7

## 0.1.0 (2019-09-21)
- Initial release

==> rustsec-admin-0.4.2.crate: rustsec-admin-0.4.2/CHANGELOG.md <==
## 0.4.2 (2021-05-03)
- web: Add back an Atom feed for advisories ([#140])

[#140]: https://github.com/RustSec/rustsec-admin/pull/140

## 0.4.1 (2021-04-30)
- Display more information on the website ([#133])

[#133]: https://github.com/RustSec/rustsec-admin/pull/133

## 0.4.0 (2021-03-06)
- Use a fully Rust based solution for rendering web page ([#115])
- Use rust-embed for static assets ([#122])
- Add argument to change where website is outputted ([#123])

[#115]: https://github.com/RustSec/rustsec-admin/pull/115
[#122]: https://github.com/RustSec/rustsec-admin/pull/122
[#123]: https://github.com/RustSec/rustsec-admin/pull/123

## 0.3.5 (2021-03-06) [YANKED]

## 0.3.4 (2021-01-26)
- Bump `rustsec` crate to v0.23 ([#112])

[#112]: https://github.com/RustSec/rustsec-admin/pull/112

## 0.3.3 (2021-01-04)
- assigner: fix "new year's" bug ([#102])

[#102]: https://github.com/RustSec/rustsec-admin/pull/102

## 0.3.2 (2020-11-23) 
- Bump `rustsec` crate to v0.23.0-pre ([#96])

[#96]: https://github.com/RustSec/rustsec-admin/pull/96

## 0.3.1 (2020-10-27)
- Bump `rustsec` crate to v0.22.2 ([#88])

[#88]: https://github.com/RustSec/rustsec-admin/pull/88

## 0.3.0 (2020-10-26)
- Bump `rustsec` crate dependency to v0.22 ([#83])
- `assign-id`: fix command after V3 advisory format migration ([#79], [#81])

[#83]: https://github.com/RustSec/rustsec-admin/pull/83
[#81]: https://github.com/RustSec/rustsec-admin/pull/81
[#79]: https://github.com/RustSec/rustsec-admin/pull/79

## 0.2.1 (2020-07-24)
- Output mode for use with the production github action ([#62])

[#62]: https://github.com/RustSec/rustsec-admin/pull/62

## 0.2.0 (2020-06-29)
- linter: refactor into `Linter` struct; check all files ([#55])
- Bump `rustsec` crate to v0.21.0 ([#52])
- `assign-id` subcommand ([#41])

[#55]: https://github.com/RustSec/rustsec-admin/pull/55
[#52]: https://github.com/RustSec/rustsec-admin/pull/52
[#41]: https://github.com/RustSec/rustsec-admin/pull/41

## 0.1.1 (2019-10-07)
- Bump `rustsec` crate to v0.15.1 ([#7])

[#7]: https://github.com/RustSec/rustsec-admin/pull/7

## 0.1.0 (2019-09-21)
- Initial release
